@@ -1,5 +1,5 @@
 #
-# Copyright 2011-2014 Red Hat, Inc.
+# Copyright 2011-2020 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@ from __future__ import division
 
 import six
 
-ERR_OK = 0
 ERR_BAD_PARAMS = 21
 ERR_BAD_ADDR = 22
 ERR_BAD_NIC = 23
@@ -31,9 +30,7 @@ ERR_USED_NIC = 24
 ERR_BAD_BONDING = 25
 ERR_BAD_VLAN = 26
 ERR_BAD_BRIDGE = 27
-ERR_USED_BRIDGE = 28
 ERR_FAILED_IFUP = 29
-ERR_FAILED_IFDOWN = 30
 ERR_USED_BOND = 31
 ERR_LOST_CONNECTION = 10  # noConPeer
 ERR_OVS_CONNECTION = 32
