@@ -1,4 +1,4 @@
-# Copyright 2016-2018 Red Hat, Inc.
+# Copyright 2016-2020 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -118,10 +118,6 @@ class IfaceAPI(object):
     def mtu(self):
         pass
 
-    @abc.abstractmethod
-    def set_mtu(self, mtu):
-        pass
-
     @abc.abstractmethod
     def type(self):
         pass
@@ -217,10 +213,6 @@ class IfaceHybrid(IfaceAPI):
     def mtu(self):
         return self.properties()['mtu']
 
-    def set_mtu(self, mtu):
-        link_set_args = ['mtu', str(mtu)]
-        ipwrapper.linkSet(self._dev, link_set_args)
-
     def type(self):
         if self._is_dpdk_type:
             return Type.DPDK
